==> xwidgetsbase-8.3.1.tar.gz: lib/XWidgets/XDD/XDDSearch.dart <==
part of xwidgetbase;

class XDDSearch<T> extends StatefulWidget {
  XDDSearch({
    Key? key,
    required this.liItems,
    required this.colorStyleDD,
    required this.onChangedItemOfDD,
    required this.labelOfDD,
    this.colorOfTitleDD,
    this.propToShowInItems,
    this.itemWidgetBuilder,
    this.backGroundColorForPopUp,
    this.colorForSearchBoxBorder,
    this.clearBTN,
    this.onPressedClearButton,
    this.dropdownSearchBaseStyle,
    this.selectedItem,
    this.colorThemeForStyle,
    this.colorBorderANDlabel,
    this.colorIconClear,
    this.dropDownButton,
    this.colorOfLabel,
  }) : super(key: key);
  T? selectedItem;
  final List<T> liItems;
  final Color? colorStyleDD;
  final Color? backGroundColorForPopUp;
  final Color? colorForSearchBoxBorder;
  final ValueChanged? onChangedItemOfDD;
  final String? labelOfDD;
  final Color? colorOfTitleDD;
  final String? propToShowInItems;
  final Function()? onPressedClearButton;
  final Widget? clearBTN;
  final Widget? dropDownButton;
  final TextStyle? dropdownSearchBaseStyle;
  final DropdownSearchPopupItemBuilder? itemWidgetBuilder;
  final Color? colorThemeForStyle;
  final Color? colorBorderANDlabel;
  final Color? colorIconClear;
  final Color? colorOfLabel;
  @override
  _XDDSearchState<T> createState() => _XDDSearchState<T>();
}

class _XDDSearchState<T> extends State<XDDSearch> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
      dropdownButtonProps: DropdownButtonProps(
        constraints: BoxConstraints(maxHeight: 100, minHeight: 70),
        color: widget.colorStyleDD,
        icon: widget.dropDownButton ?? Icon(Icons.arrow_downward_sharp, color: widget.colorIconClear ?? Colors.black),
      ),
      dropdownDecoratorProps: DropDownDecoratorProps(
          dropdownSearchDecoration: InputDecoration(
            contentPadding: EdgeInsets.only(left: 1),
            hintText: "",
            floatingLabelBehavior: FloatingLabelBehavior.never,
            label: Text(widget.labelOfDD ?? "", style: XStyles.xStyTextForDescr(widget.colorOfLabel)),
            fillColor: widget.colorStyleDD,
            filled: true,
            labelStyle: XStyles.xStyTextForSubDescr(Colors.black),
            hintStyle: XStyles.xStyTextForSubDescr(Colors.black),
            border: inputDecorationForDD(Colors.white),
            disabledBorder: inputDecorationForDD(Colors.white),
            enabledBorder: inputDecorationForDD(Colors.white),
          ),
          baseStyle: widget.dropdownSearchBaseStyle ?? XStyles.xStyTextForSubDescr(Colors.black)),
      // mode: Mode.DIALOG,
      popupProps: PopupProps.dialog(
        searchFieldProps: TextFieldProps(
          decoration: inputDecorationDD_searchBox(),
        ),
        fit: FlexFit.loose,
        showSearchBox: true,
        title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
        dialogProps: DialogProps(backgroundColor: widget.backGroundColorForPopUp ?? widget.colorStyleDD),
        itemBuilder: widget.itemWidgetBuilder != null
            ? widget.itemWidgetBuilder
            : ((context, item, isSelected) {
                return Card(child: Container(height: 35, alignment: Alignment.center, child: Text((item as dynamic)[widget.propToShowInItems!])));
              }),
      ),
      items: widget.liItems as List<T>,
      selectedItem: widget.selectedItem,
      clearButtonProps: ClearButtonProps(
        icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.colorIconClear ?? Colors.black),
        isVisible: true,
      ),
      onChanged: (value) {
        widget.onChangedItemOfDD!(value);
      },
      itemAsString: (i) => widget.propToShowInItems == null ? i : (i as dynamic)[widget.propToShowInItems!],
      // serve solo per avere il valore iniziale      selectedItem: _objForDD == null ? _objForDD : (_objForDD as dynamic)[widget.propToShowInItems!],
    );
    return Theme(
        data: ThemeData(
            // textTheme: TextTheme(subtitle1: TextStyle(color: widget.colorThemeForStyle ?? Colors.black)),
            ),
        child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Color(0xFF57cc99)),
      border: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(Colors.black),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.black),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
    );
  }
}

==> xwidgetsbase-8.3.8.tar.gz: lib/XWidgets/XDD/XDDSearch.dart <==
part of xwidgetbase;

class XDDSearch<T> extends StatefulWidget {
  XDDSearch({
    Key? key,
    required this.liItems,
    required this.colorStyleDD,
    required this.onChangedItemOfDD,
    required this.labelOfDD,
    this.colorOfTitleDD,
    this.propToShowInItems,
    this.itemWidgetBuilder,
    this.backGroundColorForPopUp,
    this.colorForSearchBoxBorder,
    this.clearBTN,
    this.onPressedClearButton,
    this.dropdownSearchBaseStyle,
    this.selectedItem,
    this.colorThemeForStyle,
    this.colorBorderANDlabel,
    this.colorIconClear,
    this.dropDownButton,
    this.colorOfLabel,
    this.itemAsString,
  }) : super(key: key);
  T? selectedItem;
  final List<T> liItems;
  final Color? colorStyleDD;
  final Color? backGroundColorForPopUp;
  final Color? colorForSearchBoxBorder;
  final ValueChanged? onChangedItemOfDD;
  final String? labelOfDD;
  final Color? colorOfTitleDD;
  final String? propToShowInItems;
  final Function()? onPressedClearButton;
  final Widget? clearBTN;
  final Widget? dropDownButton;
  final TextStyle? dropdownSearchBaseStyle;
  final DropdownSearchPopupItemBuilder? itemWidgetBuilder;
  final Color? colorThemeForStyle;
  final Color? colorBorderANDlabel;
  final Color? colorIconClear;
  final Color? colorOfLabel;
  final String Function(T)? itemAsString;
  @override
  _XDDSearchState<T> createState() => _XDDSearchState<T>();
}

class _XDDSearchState<T> extends State<XDDSearch<T>> {
  DropdownSearch<T>? internalDDwidget;
  @override
  void initState() {
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    internalDDwidget = DropdownSearch<T>(
      dropdownButtonProps: DropdownButtonProps(
        constraints: BoxConstraints(maxHeight: 100, minHeight: 70),
        color: widget.colorStyleDD,
        icon: widget.dropDownButton ?? Icon(Icons.arrow_downward_sharp, color: widget.colorIconClear ?? Colors.black),
      ),
      dropdownDecoratorProps: DropDownDecoratorProps(
          dropdownSearchDecoration: InputDecoration(
            contentPadding: EdgeInsets.only(left: 1),
            hintText: "",
            floatingLabelBehavior: FloatingLabelBehavior.never,
            label: Text(widget.labelOfDD ?? "", style: XStyles.xStyTextForDescr(widget.colorOfLabel)),
            fillColor: widget.colorStyleDD,
            filled: true,
            labelStyle: XStyles.xStyTextForSubDescr(widget.colorOfLabel ?? Colors.black),
            hintStyle: XStyles.xStyTextForSubDescr(widget.colorOfLabel ?? Colors.black),
            border: inputDecorationForDD(Colors.white),
            disabledBorder: inputDecorationForDD(Colors.white),
            enabledBorder: inputDecorationForDD(Colors.white),
          ),
          baseStyle: widget.dropdownSearchBaseStyle ?? XStyles.xStyTextForSubDescr(widget.colorOfLabel)),
      // mode: Mode.DIALOG,
      popupProps: PopupProps.dialog(
        searchFieldProps: TextFieldProps(
          decoration: inputDecorationDD_searchBox(),
        ),
        fit: FlexFit.loose,
        showSearchBox: true,
        title: Row(mainAxisAlignment: MainAxisAlignment.center, children: [Container(margin: EdgeInsets.only(top: 7), child: Text(widget.labelOfDD ?? "<No Title>", style: XStyles.xStyTextForDescr(widget.colorOfTitleDD ?? Colors.black)))]),
        dialogProps: DialogProps(backgroundColor: widget.backGroundColorForPopUp ?? widget.colorStyleDD),
        itemBuilder: widget.itemWidgetBuilder != null
            ? widget.itemWidgetBuilder
            : ((context, item, isSelected) {
                return Card(child: Container(height: 35, alignment: Alignment.center, child: Text((item as dynamic)[widget.propToShowInItems!])));
              }),
      ),
      items: widget.liItems,
      selectedItem: widget.selectedItem,
      clearButtonProps: ClearButtonProps(
        icon: widget.clearBTN ?? Icon(Icons.clear, color: widget.colorIconClear ?? Colors.black),
        isVisible: true,
      ),
      onChanged: (value) {
        widget.onChangedItemOfDD!(value);
      },
      itemAsString: widget.itemAsString != null ? ((value) => widget.itemAsString!(value)) : ((i) => widget.propToShowInItems == null ? i : (i as dynamic)[widget.propToShowInItems]),
      // serve solo per avere il valore iniziale      selectedItem: _objForDD == null ? _objForDD : (_objForDD as dynamic)[widget.propToShowInItems!],
    );
    return Theme(
        data: ThemeData(
            // textTheme: TextTheme(subtitle1: TextStyle(color: widget.colorThemeForStyle ?? Colors.black)),
            ),
        child: internalDDwidget!);
  }

  inputDecorationForDD(Color? colorBorder) {
    return OutlineInputBorder(borderSide: BorderSide(color: colorBorder ?? Colors.white));
  }

  inputDecorationDD_btn({Color? colorBorderANDlabel}) {
    return InputDecoration(
      isCollapsed: true,
      labelStyle: XStyles.xStyTextForDescr(colorBorderANDlabel ?? Color(0xFF57cc99)),
      border: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      disabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
      enabledBorder: inputDecorationForDD(colorBorderANDlabel ?? Color(0xFF57cc99)),
    );
  }

  inputDecorationDD_searchBox({Color? colorBorderANDlabelForSearchBox}) {
    return InputDecoration(
      hintText: "cerca...",
      labelStyle: XStyles.xStyTextForSubDescr(colorBorderANDlabelForSearchBox),
      hintStyle: XStyles.xStyTextForDescr(colorBorderANDlabelForSearchBox ?? Colors.black),
      border: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      disabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
      enabledBorder: inputDecorationForDD(colorBorderANDlabelForSearchBox ?? Colors.black),
    );
  }
}
